# This file was autogenerated from running 'tests/async.py'.

from pathlib import Path

from PIL import Image

from aaa1111 import AAA1111

image_png = "tests/image/test1.png"
image_webp = "tests/image/test2.webp"
image_jpg = "tests/image/test3.jpg"


class TestInfo:
    api = AAA1111(username="aaa1111", password="test")

    async def test_png_info1(self):
        resp = await self.api.apng_info(image_png)
        assert resp.info.startswith("masterpiece")
        assert "parameters" in resp.items

    async def test_png_info2(self):
        resp = await self.api.apng_info(image_webp)
        assert not resp.info
        assert "parameters" in resp.items

    async def test_png_info3(self):
        resp = await self.api.apng_info(Path(image_jpg))
        assert not resp.info
        assert "parameters" in resp.items

    async def test_png_info4(self):
        pil = Image.open(image_png)
        resp = await self.api.apng_info(pil)
        assert resp.info.startswith("masterpiece")
        assert "parameters" in resp.items

    async def test_png_info5(self):
        pil = Image.open(image_png).convert("L")
        resp = await self.api.apng_info(pil)
        assert resp.info.startswith("masterpiece")
        assert "parameters" in resp.items

    async def test_progress(self):
        resp = await self.api.aprogress()
        assert resp.current_image is None
        assert "job_count" in resp.state

    async def test_cmd_flags(self):
        resp = await self.api.acmd_flags()
        assert "api" in resp

    async def test_samplers(self):
        resp = await self.api.asamplers()
        assert resp
        assert "Euler" in [item.name for item in resp]

    async def test_upscalers(self):
        resp = await self.api.aupscalers()
        assert resp
        assert "Nearest" in [item.name for item in resp]

    async def test_latent_upscale_modes(self):
        resp = await self.api.alatent_upscale_modes()
        assert resp
        assert "Latent (bicubic)" in [item.name for item in resp]

    async def test_sd_models(self):
        resp = await self.api.asd_models()
        assert resp
        assert any(item.model_name.startswith("Counterfeit") for item in resp)
        assert "5998292c04" in [item.hash for item in resp]

    async def test_sd_vae(self):
        resp = await self.api.asd_vae()
        assert resp
        assert any(item.model_name.startswith("kl-f8-anime2") for item in resp)

    async def test_hypernetworks(self):
        resp = await self.api.ahypernetworks()
        assert not resp

    async def test_face_restorers(self):
        resp = await self.api.aface_restorers()
        assert resp
        assert "CodeFormer" in [item.name for item in resp]

    async def test_realesrgan_models(self):
        resp = await self.api.arealesrgan_models()
        assert resp
        assert any(item.name.startswith("R-ESRGAN") for item in resp)

    async def test_prompt_styles(self):
        resp = await self.api.aprompt_styles()
        assert resp
        assert any(item.name.startswith("default") for item in resp)

    async def test_embeddings(self):
        resp = await self.api.aembeddings()
        assert resp.loaded
        assert any(item.startswith("EasyNegative") for item in resp.loaded)

    async def test_memory(self):
        resp = await self.api.amemory()
        assert resp.cuda
        assert resp.ram

    async def test_scripts(self):
        resp = await self.api.ascripts()
        assert resp.txt2img
        assert resp.img2img
        assert any("adetailer" in item for item in resp.txt2img)
        assert any("controlnet" in item for item in resp.img2img)

    async def test_script_info(self):
        resp = await self.api.ascript_info()
        assert resp
        assert any(item.is_alwayson for item in resp)
        assert any(item.name == "controlnet" for item in resp)

    async def test_loras(self):
        resp = await self.api.aloras()
        assert resp
        assert any(item.name.startswith("add_detail") for item in resp)
